@@ -1,13 +1,23 @@
 # -*- coding: utf-8 -*-
 import os
 
-from mkr.core.mkp import MicroKernelPluginManager
+from mkr.core.mkp import MKPluginManager
 
 
 class MicroKernel:
     """
     微核架构 - 基于外部内核框架
-    提供python插件管理(目前很脆弱, python插件做成独立python项目的形式，最后在其中加入__init__.py作为mod入口)
+    提供python插件管理(python插件做成独立python项目的形式，最后在其中加入__init__.py作为mod入口)
+    NOTE: 你做的python插件中引用资源时，该资源路径必须以r或rf开头。(同理，以r开头的字符串会被当作一个资源文件的路径)
+        例如:
+            引用当前目录下的a.png:
+            path = r"a.png"
+            或
+            txt = 'a'
+            path = rf"{txt}.png"
+        错误示例:
+            name = r"jack"  # 非路径使用r或rf开头
+
     NOTE: 你做的python插件在import时小心和mk项目中的文件重名，不然可能会出现循环导入
     通过.add方法返回插件对象, 成功启动微核后，可以通过插件对象.code访问到上述__init__.py的内容
     """
@@ -23,7 +33,7 @@ class MicroKernel:
         self.plugin_path = os.path.abspath(plugin_path_name)
 
         # 添加组件
-        self.mkpm = MicroKernelPluginManager(self.path)
+        self.mkpm = MKPluginManager(self.path)
         self.packos = self.mkpm.packos
 
         # 初始化mod目录
@@ -59,6 +69,11 @@ class MicroKernel:
         return self.mkpm.remove(name)
 
     def loadmods(self):
+        """
+        在plugin_path下加载mod
+        该函数自动执行，不必由用户操作
+        :return:
+        """
         for fname in os.listdir(self.plugin_path):
             get = os.path.join(self.plugin_path, fname)
             if os.path.isdir(get):
